==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/tooling/maven/camel-api-component-maven-plugin/src/main/java/org/apache/camel/maven/FileApiMethodGeneratorMojo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.maven;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.plugins.annotations.ResolutionScope;

/**
 * Parses ApiMethod signatures from a File.
 */
@Mojo(name = "fromFile", requiresDependencyResolution = ResolutionScope.COMPILE_PLUS_RUNTIME, requiresProject = true,
        defaultPhase = LifecyclePhase.GENERATE_SOURCES, threadSafe = true)
public class FileApiMethodGeneratorMojo extends AbstractApiMethodGeneratorMojo {

    @Parameter(required = true, property = PREFIX + "signatureFile")
    protected File signatureFile;

    @Override
    public List<String> getSignatureList() throws MojoExecutionException {
        // get signatureFile as a list of Strings
        List<String> result = new ArrayList<>();
        try {
            BufferedReader reader = new BufferedReader(new FileReader(this.signatureFile));
            String line = reader.readLine();
            while (line != null) {
                result.add(line);
                line = reader.readLine();
            }
            reader.close();
        } catch (IOException e) {
            throw new MojoExecutionException(e.getMessage(), e);
        }
        if (result.isEmpty()) {
            throw new MojoExecutionException("Signature file " + signatureFile.getPath() + " is empty");
        }
        return result;
    }
}

==> apache-camel-3.5.0-src.zip: apache-camel-3.5.0/tooling/maven/camel-api-component-maven-plugin/src/main/java/org/apache/camel/maven/FileApiMethodGeneratorMojo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.maven;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.plugins.annotations.ResolutionScope;

/**
 * Parses ApiMethod signatures from a File.
 */
@Mojo(name = "fromFile", requiresDependencyResolution = ResolutionScope.COMPILE_PLUS_RUNTIME, requiresProject = true,
      defaultPhase = LifecyclePhase.GENERATE_SOURCES, threadSafe = true)
public class FileApiMethodGeneratorMojo extends AbstractApiMethodGeneratorMojo {

    @Parameter(required = true, property = PREFIX + "signatureFile")
    protected File signatureFile;

    @Override
    public List<SignatureModel> getSignatureList() throws MojoExecutionException {
        // get signatureFile as a list of Strings
        List<SignatureModel> result = new ArrayList<>();
        try {
            BufferedReader reader = new BufferedReader(new FileReader(this.signatureFile));
            String line = reader.readLine();
            while (line != null) {
                SignatureModel model = new SignatureModel();
                model.setSignature(line);
                result.add(model);
                line = reader.readLine();
            }
            reader.close();
        } catch (IOException e) {
            throw new MojoExecutionException(e.getMessage(), e);
        }
        if (result.isEmpty()) {
            throw new MojoExecutionException("Signature file " + signatureFile.getPath() + " is empty");
        }
        return result;
    }
}
